@@ -72,6 +72,7 @@
 #include <qqmlfileselector.h>
 #include <qqmllist.h>
 #include <qqmlpropertymap.h>
+#include <qqml.h>
 #include <qqmlengine.h>
 #include <qqmlfile.h>
 #include <qqmlcontext.h>
@@ -138,8 +139,9 @@ enum : int {
     SBK_QQMLPROPERTYVALUESOURCE_IDX                          = 40,
     SBK_QQMLSCRIPTSTRING_IDX                                 = 41,
     SBK_QQMLTYPESEXTENSIONINTERFACE_IDX                      = 42,
+    SBK_QTQML_IDX                                            = 43,
     SBK_QML_HAS_ATTACHED_PROPERTIES_IDX                      = 7,
-    SBK_QtQml_IDX_COUNT                                      = 43
+    SBK_QtQml_IDX_COUNT                                      = 44
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtQmlTypes;
