@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 
@@ -62,58 +56,63 @@
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
-#include <signalmanager.h>
 #include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QStack>
+#include <pysideqflags.h>
+#include <QLinkedList>
 #include <QList>
 #include <QMap>
-#include <pysideqflags.h>
+#include <QMultiMap>
 #include <QPair>
 #include <QQueue>
-#include <QMultiMap>
 #include <QSet>
-#include <QLinkedList>
+#include <QStack>
 #include <QVector>
 
 // Type indices
-#define SBK_QVOICE_IDX                                               3
-#define SBK_QVOICE_GENDER_IDX                                        5
-#define SBK_QVOICE_AGE_IDX                                           4
-#define SBK_QTEXTTOSPEECHENGINE_IDX                                  2
-#define SBK_QTEXTTOSPEECH_IDX                                        0
-#define SBK_QTEXTTOSPEECH_STATE_IDX                                  1
-#define SBK_QtTextToSpeech_IDX_COUNT                                 6
-
+enum : int {
+    SBK_QTEXTTOSPEECH_IDX                                    = 0,
+    SBK_QTEXTTOSPEECH_STATE_IDX                              = 1,
+    SBK_QTEXTTOSPEECHENGINE_IDX                              = 2,
+    SBK_QVOICE_IDX                                           = 3,
+    SBK_QVOICE_GENDER_IDX                                    = 5,
+    SBK_QVOICE_AGE_IDX                                       = 4,
+    SBK_QtTextToSpeech_IDX_COUNT                             = 6
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtTextToSpeechTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtTextToSpeechModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtTextToSpeechTypeConverters;
 
 // Converter indices
-#define SBK_QTTEXTTOSPEECH_QVECTOR_QLOCALE_IDX                       0 // QVector<QLocale >
-#define SBK_QTTEXTTOSPEECH_QVECTOR_QVOICE_IDX                        1 // QVector<QVoice >
-#define SBK_QTTEXTTOSPEECH_QLIST_QOBJECTPTR_IDX                      2 // const QList<QObject* > &
-#define SBK_QTTEXTTOSPEECH_QLIST_QBYTEARRAY_IDX                      3 // QList<QByteArray >
-#define SBK_QTTEXTTOSPEECH_QLIST_QVARIANT_IDX                        4 // QList<QVariant >
-#define SBK_QTTEXTTOSPEECH_QLIST_QSTRING_IDX                         5 // QList<QString >
-#define SBK_QTTEXTTOSPEECH_QMAP_QSTRING_QVARIANT_IDX                 6 // QMap<QString,QVariant >
-#define SBK_QtTextToSpeech_CONVERTERS_IDX_COUNT                      7
-
+enum : int {
+    SBK_QTTEXTTOSPEECH_QVECTOR_QLOCALE_IDX                   = 0, // QVector<QLocale >
+    SBK_QTTEXTTOSPEECH_QVECTOR_QVOICE_IDX                    = 1, // QVector<QVoice >
+    SBK_QTTEXTTOSPEECH_QLIST_QOBJECTPTR_IDX                  = 2, // const QList<QObject* > &
+    SBK_QTTEXTTOSPEECH_QLIST_QBYTEARRAY_IDX                  = 3, // QList<QByteArray >
+    SBK_QTTEXTTOSPEECH_QLIST_QVARIANT_IDX                    = 4, // QList<QVariant >
+    SBK_QTTEXTTOSPEECH_QLIST_QSTRING_IDX                     = 5, // QList<QString >
+    SBK_QTTEXTTOSPEECH_QMAP_QSTRING_QVARIANT_IDX             = 6, // QMap<QString,QVariant >
+    SBK_QtTextToSpeech_CONVERTERS_IDX_COUNT                  = 7
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+template<> inline PyTypeObject* SbkType< ::QTextToSpeech::State >() { return SbkPySide2_QtTextToSpeechTypes[SBK_QTEXTTOSPEECH_STATE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QTextToSpeech >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtTextToSpeechTypes[SBK_QTEXTTOSPEECH_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QTextToSpeechEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtTextToSpeechTypes[SBK_QTEXTTOSPEECHENGINE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QVoice::Gender >() { return SbkPySide2_QtTextToSpeechTypes[SBK_QVOICE_GENDER_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QVoice::Age >() { return SbkPySide2_QtTextToSpeechTypes[SBK_QVOICE_AGE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QVoice >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtTextToSpeechTypes[SBK_QVOICE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QTextToSpeechEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtTextToSpeechTypes[SBK_QTEXTTOSPEECHENGINE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QTextToSpeech::State >() { return SbkPySide2_QtTextToSpeechTypes[SBK_QTEXTTOSPEECH_STATE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QTextToSpeech >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtTextToSpeechTypes[SBK_QTEXTTOSPEECH_IDX]); }
 
 } // namespace Shiboken
 
